@@ -58,7 +58,7 @@
 #define GPM_AUTO_SAVE_INTERVAL		GPM_SAVE_DIR "/auto_save_interval"
 
 #define GPM_UNDO_DIR			GPM_PREFS_DIR  "/editor/undo"
-#define GPM_UNDO_ACTIONS_LIMIT		GPM_UNDO_DIR "/undo_actions_limit"
+#define GPM_UNDO_ACTIONS_LIMIT		GPM_UNDO_DIR "/max_undo_actions"
 
 #define GPM_WRAP_MODE_DIR		GPM_PREFS_DIR "/editor/wrap_mode"
 #define GPM_WRAP_MODE			GPM_WRAP_MODE_DIR "/wrap_mode"
@@ -73,6 +73,12 @@
 #define GPM_LINE_NUMBERS_DIR		GPM_PREFS_DIR "/editor/line_numbers"
 #define GPM_DISPLAY_LINE_NUMBERS 	GPM_LINE_NUMBERS_DIR "/display_line_numbers"
 
+#define GPM_CURRENT_LINE_DIR		GPM_PREFS_DIR "/editor/current_line"
+#define GPM_HIGHLIGHT_CURRENT_LINE 	GPM_CURRENT_LINE_DIR "/highlight_current_line"
+
+#define GPM_BRACKET_MATCHING_DIR	GPM_PREFS_DIR "/editor/bracket_matching"
+#define GPM_BRACKET_MATCHING		GPM_BRACKET_MATCHING_DIR "/bracket_matching"
+
 #define GPM_RIGHT_MARGIN_DIR		GPM_PREFS_DIR "/editor/right_margin"
 #define GPM_DISPLAY_RIGHT_MARGIN	GPM_RIGHT_MARGIN_DIR "/display_right_margin"
 #define GPM_RIGHT_MARGIN_POSITION	GPM_RIGHT_MARGIN_DIR "/right_margin_position"
@@ -135,7 +141,7 @@
 #define GPM_DEFAULT_AUTO_SAVE		0 /* FALSE */
 #define GPM_DEFAULT_AUTO_SAVE_INTERVAL	10 /* minutes */
 
-#define GPM_DEFAULT_UNDO_ACTIONS_LIMIT	25 /* actions */
+#define GPM_DEFAULT_UNDO_ACTIONS_LIMIT	2000 /* actions */
 
 #define GPM_DEFAULT_WRAP_MODE		"GTK_WRAP_WORD"
 
@@ -173,6 +179,10 @@
 #define GPM_DEFAULT_WINDOW_WIDTH_STR	"650"
 #define GPM_DEFAULT_WINDOW_HEIGHT_STR	"500"
 
+#define GPM_DEFAULT_HIGHLIGHT_CURRENT_LINE  1 /* TRUE */
+
+#define GPM_DEFAULT_BRACKET_MATCHING	  0 /* FALSE */
+
 #define GPM_DEFAULT_DISPLAY_RIGHT_MARGIN  0 /* FALSE */
 #define GPM_DEFAULT_RIGHT_MARGIN_POSITION 80
 
@@ -344,6 +354,16 @@ GSList			*gedit_prefs_manager_get_shown_in_menu_encodings (void);
 void			 gedit_prefs_manager_set_shown_in_menu_encodings (const GSList *encs);
 gboolean 		 gedit_prefs_manager_shown_in_menu_encodings_can_set (void);
 
+/* Highlight current line */
+gboolean		 gedit_prefs_manager_get_highlight_current_line	(void);
+void			 gedit_prefs_manager_set_highlight_current_line	(gboolean hl);
+gboolean		 gedit_prefs_manager_highlight_current_line_can_set (void);
+
+/* Highlight matching bracket */
+gboolean		 gedit_prefs_manager_get_bracket_matching	(void);
+void			 gedit_prefs_manager_set_bracket_matching	(gboolean bm);
+gboolean		 gedit_prefs_manager_bracket_matching_can_set (void);
+
 /* Display right margin */
 gboolean		 gedit_prefs_manager_get_display_right_margin	(void);
 void			 gedit_prefs_manager_set_display_right_margin	(gboolean drm);
